translate.convert.po2sub

Package translate :: Package convert :: Module po2sub |
[hide private]
[frames] | no frames]

# Module po2sub

source code

Convert Gettext PO localization files to subtitle files

Classes | [hide private]
| resub

Functions | [hide private]
convertsub(inputfile, outputfile, templatefile, includefuzzy=False) | source code
main(argv=None) | source code

Variables | [hide private]
| __package__ = ``'``translate.convert``'``

Imports: factory